/*
 ThermostatQA - test framework for Thermostat Monitoring Tool

 Copyright 2015 Red Hat, Inc.

 This file is part of ThermostatQA

 ThermostatQA is distributed under the GNU General Public License,
 version 2 or any later version (with a special exception described
 below, commonly known as the "Classpath Exception").

 A copy of GNU General Public License (GPL) is included in this
 distribution, in the file COPYING.

 Linking ThermostatQA code with other modules is making a combined work
 based on ThermostatQA.  Thus, the terms and conditions of the GPL
 cover the whole combination.

 As a special exception, the copyright holders of ThermostatQA give you
 permission to link this code with independent modules to produce an
 executable, regardless of the license terms of these independent
 modules, and to copy and distribute the resulting executable under
 terms of your choice, provided that you also meet, for each linked
 independent module, the terms and conditions of the license of that
 module.  An independent module is a module which is not derived from
 or based on ThermostatQA code.  If you modify ThermostatQA, you may
 extend this exception to your version of the software, but you are
 not obligated to do so.  If you do not wish to do so, delete this
 exception statement from your version.
 */
package org.thermostat.qa2.reporter;

import java.awt.Dimension;
import org.thermostat.qa2.reporter.result.TestRunResult;
import java.io.File;
import java.io.IOException;
import java.util.ArrayList;
import java.util.Arrays;
import java.util.List;
import org.thermostat.qa.reporter.ResultsGraphGenerator;
import org.thermostat.qa.reporter.TestResult;
import org.thermostat.qa2.framework.ThermostatQAConfig;
import org.thermostat.qa2.framework.utils.FileUtilities;

/**
 *
 * @author Zdeněk Žamberský
 */
public class Reporter {

    public static void generateReport() throws IOException {
        File logsDir = new File(ThermostatQAConfig.logsDir);
        File[] runDirs = logsDir.listFiles();
        Arrays.sort(runDirs);

        int runsCount = runDirs.length;
        int limit = 30;
        if (runsCount > 0) {
            List<TestRunResult> runs = new ArrayList();
            for (int i = Math.max(0, runsCount - limit); i < runsCount; ++i) {
                TestRunResult run = LogParser.parseLogDir(runDirs[i]);
                runs.add(run);
            }
            TestRunResult lastRun = runs.get(runs.size() - 1);

            // index page
            String indexPagePath = ThermostatQAConfig.reportDir + File.separator + "index.xhtml";
            List<String> indexPageText = new ArrayList();
            Generator.generateIndexPage(indexPageText, lastRun);
            FileUtilities.printLineListToFile(indexPagePath, indexPageText);

            // log page
            String logPagePath = ThermostatQAConfig.reportDir + File.separator + "log_" + lastRun.date + ".xhtml";
            List<String> logPageText = new ArrayList();
            Generator.generateLogPage(logPageText, lastRun);
            FileUtilities.printLineListToFile(logPagePath, logPageText);

            // history pages
            String[] fileNames = {"hist_all_tests", "hist_failed_tests", "hist_10", "hist_20", "hist_30"};
            String[] labels = {"all tests", "failed tests", "last 10 results", "last 20 results", "last 30 results"};
            int[] counts = {30, 30, 10, 20, 30};
            boolean[] onlyFailed = {false, true, true, true, true};

            for (int i = 0; i < fileNames.length; ++i) {
                String historyPagePath = ThermostatQAConfig.reportDir + File.separator + fileNames[i] + ".xhtml";
                List<String> historyPageText = new ArrayList();
                Generator.generateHistoryPage(historyPageText, runs, labels[i], counts[i], onlyFailed[i]);
                FileUtilities.printLineListToFile(historyPagePath, historyPageText);
            }

            // graphs pages
            fileNames = new String[]{"graph_all", "graph_10", "graph_20", "graph_30"};
            counts = new int[]{30, 10, 20, 30};
            for (int i = 0; i < fileNames.length; ++i) {
                String graphsPagePath = ThermostatQAConfig.reportDir + File.separator + fileNames[i] + ".xhtml";
                List<String> graphPageText = new ArrayList();
                Generator.generateGraphPage(graphPageText, runs, counts[i]);
                FileUtilities.printLineListToFile(graphsPagePath, graphPageText);
            }

            // generate image using old reporter
            Dimension graphSize = new Dimension(256, 256);
            TestResult testResult = new TestResult(lastRun.passedCount, lastRun.failedCount, lastRun.errorCount, lastRun.ignoredCount);
            (new ResultsGraphGenerator()).generateGraph(testResult, graphSize, ThermostatQAConfig.reportDir + File.separator + "graph.png");
        }
    }

    public static void main(String[] args) throws IOException {
        generateReport();
    }

}
